Package 'pacta.portfolio.report'

Title: pacta.portfolio.report
Description: For more information visit <https://rmi.org/>.
Authors: Monika Furdyna [aut, cre, ctr] (ORCID: <https://orcid.org/0000-0002-3728-0646>), CJ Yetman [aut, ctr] (ORCID: <https://orcid.org/0000-0001-5099-9500>), Jackson Hoffart [aut, ctr] (ORCID: <https://orcid.org/0000-0002-8600-5042>), Jacob Kastl [aut, ctr], Alex Axthelm [aut, ctr] (ORCID: <https://orcid.org/0000-0001-8579-8565>), Rocky Mountain Institute [cph, fnd]
Maintainer: Monika Furdyna <[email protected]>
License: MIT + file LICENSE
Version: 0.4.1.9001
Built: 2026-05-25 06:04:16 UTC
Source: https://github.com/rmi-pacta/pacta.portfolio.report

Help Index


Create interactive report

Description

This function creates an interactive report

Usage

create_interactive_report(
  template_dir = NULL,
  output_dir = NULL,
  survey_dir = "",
  real_estate_dir = "",
  language_select = "EN",
  investor_name = NULL,
  portfolio_name = NULL,
  peer_group = NULL,
  start_year = NULL,
  select_scenario,
  select_scenario_other,
  portfolio_allocation_method = NULL,
  scenario_geography = NULL,
  pacta_sectors = c("Power", "Automotive", "Oil&Gas", "Coal", "Steel", "Cement",
    "Aviation"),
  green_techs = c("RenewablesCap", "HydroCap", "NuclearCap", "Hybrid", "Electric",
    "FuelCell", "Hybrid_HDV", "Electric_HDV", "FuelCell_HDV", "Electric Arc Furnace"),
  tech_roadmap_sectors = c("Automotive", "Power", "Oil&Gas", "Coal"),
  pacta_sectors_not_analysed = c("Aviation", "Cement", "Steel"),
  audit_file = NULL,
  emissions = NULL,
  portfolio_overview = NULL,
  equity_results_portfolio = NULL,
  bonds_results_portfolio = NULL,
  equity_results_company = NULL,
  bonds_results_company = NULL,
  equity_results_map = NULL,
  bonds_results_map = NULL,
  indices_equity_results_portfolio = NULL,
  indices_bonds_results_portfolio = NULL,
  peers_equity_results_portfolio = NULL,
  peers_bonds_results_portfolio = NULL,
  peers_equity_results_user = NULL,
  peers_bonds_results_user = NULL,
  display_currency = "USD",
  currency_exchange_value = 1,
  dataframe_translations = NULL,
  js_translations = NULL,
  header_dictionary = NULL,
  sector_order = NULL,
  configs = NULL
)

Arguments

template_dir

a parameter

output_dir

a parameter

survey_dir

a parameter

real_estate_dir

a parameter

language_select

a parameter

investor_name

a parameter

portfolio_name

a parameter

peer_group

a parameter

start_year

a parameter

select_scenario

a parameter

select_scenario_other

a parameter

portfolio_allocation_method

a parameter

scenario_geography

a parameter

pacta_sectors

a parameter

green_techs

a parameter

tech_roadmap_sectors

a parameter

pacta_sectors_not_analysed

a parameter

audit_file

a parameter

emissions

a parameter

portfolio_overview

a parameter

equity_results_portfolio

a parameter

bonds_results_portfolio

a parameter

equity_results_company

a parameter

bonds_results_company

a parameter

equity_results_map

a parameter

bonds_results_map

a parameter

indices_equity_results_portfolio

a parameter

indices_bonds_results_portfolio

a parameter

peers_equity_results_portfolio

a parameter

peers_bonds_results_portfolio

a parameter

peers_equity_results_user

a parameter

peers_bonds_results_user

a parameter

display_currency

a parameter

currency_exchange_value

a parameter

dataframe_translations

a parameter

js_translations

a parameter

header_dictionary

a parameter

sector_order

a parameter

configs

a parameter

Value

only used for side-effect


Get the path to the template based on report name and language

Description

This function returns the path to the template based on the report name and the language code. The templates are installed with the package. If a template is not found that corresponds to the specified report name and language code, a default template is used instead.

Usage

get_report_template_path(
  project_report_name = "general",
  language_select = "EN"
)

Arguments

project_report_name

a single string specifying the name of the report, e.g. "GENERAL"

language_select

a single string specifying the name of the language code, e.g. "EN"

Value

A string containing the path to the template directory


select correct report template

Description

This function returns the name of the template

Usage

select_report_template(project_report_name = NULL, language_select = "EN")

Arguments

project_report_name

a parameter

language_select

a parameter

Value

A string containing the name of the template